@@ -1,140 +1,163 @@
-( cd opt/kde/lib ; rm -rf libkdecorations.so.4 )
-( cd opt/kde/lib ; ln -sf libkdecorations.so.4.2.0 libkdecorations.so.4 )
-( cd opt/kde/lib ; rm -rf libplasmaclock.so.4 )
-( cd opt/kde/lib ; ln -sf libplasmaclock.so.4.2.0 libplasmaclock.so.4 )
-( cd opt/kde/lib ; rm -rf libprocessui.so.4 )
-( cd opt/kde/lib ; ln -sf libprocessui.so.4.2.0 libprocessui.so.4 )
-( cd opt/kde/lib ; rm -rf libnepomukqueryclient.so.4 )
-( cd opt/kde/lib ; ln -sf libnepomukqueryclient.so.4.2.0 libnepomukqueryclient.so.4 )
-( cd opt/kde/lib ; rm -rf libplasma_applet-system-monitor.so )
-( cd opt/kde/lib ; ln -sf libplasma_applet-system-monitor.so.4 libplasma_applet-system-monitor.so )
-( cd opt/kde/lib ; rm -rf libkwinnvidiahack.so )
-( cd opt/kde/lib ; ln -sf libkwinnvidiahack.so.4 libkwinnvidiahack.so )
-( cd opt/kde/lib ; rm -rf libnepomukquery.so.4 )
-( cd opt/kde/lib ; ln -sf libnepomukquery.so.4.2.0 libnepomukquery.so.4 )
-( cd opt/kde/lib ; rm -rf libkwineffects.so.1 )
-( cd opt/kde/lib ; ln -sf libkwineffects.so.1.0.0 libkwineffects.so.1 )
-( cd opt/kde/lib ; rm -rf libsolidcontrolifaces.so.4 )
-( cd opt/kde/lib ; ln -sf libsolidcontrolifaces.so.4.2.0 libsolidcontrolifaces.so.4 )
-( cd opt/kde/lib ; rm -rf liblsofui.so )
-( cd opt/kde/lib ; ln -sf liblsofui.so.4 liblsofui.so )
-( cd opt/kde/lib ; rm -rf libprocessui.so )
-( cd opt/kde/lib ; ln -sf libprocessui.so.4 libprocessui.so )
-( cd opt/kde/lib ; rm -rf libweather_ion.so.4 )
-( cd opt/kde/lib ; ln -sf libweather_ion.so.4.2.0 libweather_ion.so.4 )
-( cd opt/kde/lib ; rm -rf libksgrd.so )
-( cd opt/kde/lib ; ln -sf libksgrd.so.4 libksgrd.so )
-( cd opt/kde/lib ; rm -rf libkwinnvidiahack.so.4 )
-( cd opt/kde/lib ; ln -sf libkwinnvidiahack.so.4.2.0 libkwinnvidiahack.so.4 )
-( cd opt/kde/lib ; rm -rf libtaskmanager.so )
-( cd opt/kde/lib ; ln -sf libtaskmanager.so.4 libtaskmanager.so )
-( cd opt/kde/lib ; rm -rf libkfontinst.so )
-( cd opt/kde/lib ; ln -sf libkfontinst.so.4 libkfontinst.so )
-( cd opt/kde/lib ; rm -rf libkephal.so )
-( cd opt/kde/lib ; ln -sf libkephal.so.4 libkephal.so )
-( cd opt/kde/lib ; rm -rf libplasma_applet-system-monitor.so.4 )
-( cd opt/kde/lib ; ln -sf libplasma_applet-system-monitor.so.4.2.0 libplasma_applet-system-monitor.so.4 )
-( cd opt/kde/lib ; rm -rf libksgrd.so.4 )
-( cd opt/kde/lib ; ln -sf libksgrd.so.4.2.0 libksgrd.so.4 )
-( cd opt/kde/lib ; rm -rf libsolidcontrol.so.4 )
-( cd opt/kde/lib ; ln -sf libsolidcontrol.so.4.2.0 libsolidcontrol.so.4 )
-( cd opt/kde/lib ; rm -rf libkephal.so.4 )
-( cd opt/kde/lib ; ln -sf libkephal.so.4.2.0 libkephal.so.4 )
-( cd opt/kde/lib ; rm -rf libkscreensaver.so )
-( cd opt/kde/lib ; ln -sf libkscreensaver.so.5 libkscreensaver.so )
-( cd opt/kde/lib ; rm -rf libkworkspace.so )
-( cd opt/kde/lib ; ln -sf libkworkspace.so.4 libkworkspace.so )
-( cd opt/kde/lib ; rm -rf libsolidcontrol.so )
-( cd opt/kde/lib ; ln -sf libsolidcontrol.so.4 libsolidcontrol.so )
-( cd opt/kde/lib ; rm -rf libkwineffects.so )
-( cd opt/kde/lib ; ln -sf libkwineffects.so.1 libkwineffects.so )
-( cd opt/kde/lib ; rm -rf libprocesscore.so.4 )
-( cd opt/kde/lib ; ln -sf libprocesscore.so.4.2.0 libprocesscore.so.4 )
-( cd opt/kde/lib ; rm -rf libplasmaclock.so )
-( cd opt/kde/lib ; ln -sf libplasmaclock.so.4 libplasmaclock.so )
-( cd opt/kde/lib ; rm -rf libkfontinst.so.4 )
-( cd opt/kde/lib ; ln -sf libkfontinst.so.4.2.0 libkfontinst.so.4 )
-( cd opt/kde/lib ; rm -rf libprocesscore.so )
-( cd opt/kde/lib ; ln -sf libprocesscore.so.4 libprocesscore.so )
-( cd opt/kde/lib ; rm -rf libkhotkeysprivate.so.4 )
-( cd opt/kde/lib ; ln -sf libkhotkeysprivate.so.4.2.0 libkhotkeysprivate.so.4 )
-( cd opt/kde/lib ; rm -rf libsolidcontrolifaces.so )
-( cd opt/kde/lib ; ln -sf libsolidcontrolifaces.so.4 libsolidcontrolifaces.so )
-( cd opt/kde/lib ; rm -rf libkscreensaver.so.5 )
-( cd opt/kde/lib ; ln -sf libkscreensaver.so.5.0.0 libkscreensaver.so.5 )
-( cd opt/kde/lib ; rm -rf libkfontinstui.so )
-( cd opt/kde/lib ; ln -sf libkfontinstui.so.4 libkfontinstui.so )
-( cd opt/kde/lib ; rm -rf libtaskmanager.so.4 )
-( cd opt/kde/lib ; ln -sf libtaskmanager.so.4.2.0 libtaskmanager.so.4 )
-( cd opt/kde/lib ; rm -rf liblsofui.so.4 )
-( cd opt/kde/lib ; ln -sf liblsofui.so.4.2.0 liblsofui.so.4 )
-( cd opt/kde/lib ; rm -rf libkfontinstui.so.4 )
-( cd opt/kde/lib ; ln -sf libkfontinstui.so.4.2.0 libkfontinstui.so.4 )
-( cd opt/kde/lib ; rm -rf libnepomukqueryclient.so )
-( cd opt/kde/lib ; ln -sf libnepomukqueryclient.so.4 libnepomukqueryclient.so )
-( cd opt/kde/lib ; rm -rf libkworkspace.so.4 )
-( cd opt/kde/lib ; ln -sf libkworkspace.so.4.2.0 libkworkspace.so.4 )
-( cd opt/kde/lib ; rm -rf libweather_ion.so )
-( cd opt/kde/lib ; ln -sf libweather_ion.so.4 libweather_ion.so )
-( cd opt/kde/lib ; rm -rf libkdecorations.so )
-( cd opt/kde/lib ; ln -sf libkdecorations.so.4 libkdecorations.so )
-( cd opt/kde/lib ; rm -rf libnepomukquery.so )
-( cd opt/kde/lib ; ln -sf libnepomukquery.so.4 libnepomukquery.so )
-( cd opt/kde/share/doc/HTML/en/kdm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kxkb ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kxkb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ksysguard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/klipper ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/klipper ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/splashscreen ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/splashscreen ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/bell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/keys ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/clock ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/fonts ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/mouse ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/powerdevil ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/powerdevil ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/fontinst ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/fontinst ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kwincompositing ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kwincompositing ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmaccess ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/colors ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/energy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmstyle ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmsmserver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/screensaver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/windowbehaviour ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/windowbehaviour ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmdisplay ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmdisplay ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kwindecoration ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/autostart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/autostart ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/joystick ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/joystick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/keyboard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/windowspecific ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/windowspecific ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/PolicyKit-kde ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/PolicyKit-kde ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/plasma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/plasma ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/powerdevil ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/powerdevil ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/windowspecific ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/windowspecific ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/desktopthemedetails ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/desktopthemedetails ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmaccess ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/energy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/screensaver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/splashscreen ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/splashscreen ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/fonts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/solid-actions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/solid-actions ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/windowbehaviour ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/windowbehaviour ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kwincompositing ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kwincompositing ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/mouse ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/bell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/colors ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/autostart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/autostart ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kwindecoration ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/joystick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/joystick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/keys ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/keyboard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmdisplay ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmdisplay ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/fontinst ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/fontinst ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmstyle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/clock ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ksysguard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kxkb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/klipper ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/klipper ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/systemsettings ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/systemsettings ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libplasmaclock.so.4 )
+( cd opt/kde/lib ; ln -sf libplasmaclock.so.4.3.0 libplasmaclock.so.4 )
+( cd opt/kde/lib ; rm -rf libkscreensaver.so.5 )
+( cd opt/kde/lib ; ln -sf libkscreensaver.so.5.0.0 libkscreensaver.so.5 )
+( cd opt/kde/lib ; rm -rf libplasma-geolocation-interface.so.4 )
+( cd opt/kde/lib ; ln -sf libplasma-geolocation-interface.so.4.3.0 libplasma-geolocation-interface.so.4 )
+( cd opt/kde/lib ; rm -rf libkephal.so.4 )
+( cd opt/kde/lib ; ln -sf libkephal.so.4.3.0 libkephal.so.4 )
+( cd opt/kde/lib ; rm -rf libkhotkeysprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libkhotkeysprivate.so.4.3.0 libkhotkeysprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libkfontinst.so.4 )
+( cd opt/kde/lib ; ln -sf libkfontinst.so.4.3.0 libkfontinst.so.4 )
+( cd opt/kde/lib ; rm -rf libkworkspace.so )
+( cd opt/kde/lib ; ln -sf libkworkspace.so.4 libkworkspace.so )
+( cd opt/kde/lib ; rm -rf libksgrd.so.4 )
+( cd opt/kde/lib ; ln -sf libksgrd.so.4.3.0 libksgrd.so.4 )
+( cd opt/kde/lib ; rm -rf libnepomukquery.so.4 )
+( cd opt/kde/lib ; ln -sf libnepomukquery.so.4.3.0 libnepomukquery.so.4 )
+( cd opt/kde/lib ; rm -rf libkwinnvidiahack.so )
+( cd opt/kde/lib ; ln -sf libkwinnvidiahack.so.4 libkwinnvidiahack.so )
+( cd opt/kde/lib ; rm -rf libprocessui.so )
+( cd opt/kde/lib ; ln -sf libprocessui.so.4 libprocessui.so )
+( cd opt/kde/lib ; rm -rf libpolkitkdeprivate.so )
+( cd opt/kde/lib ; ln -sf libpolkitkdeprivate.so.4 libpolkitkdeprivate.so )
+( cd opt/kde/lib ; rm -rf libkfontinst.so )
+( cd opt/kde/lib ; ln -sf libkfontinst.so.4 libkfontinst.so )
+( cd opt/kde/lib ; rm -rf libsolidcontrolifaces.so )
+( cd opt/kde/lib ; ln -sf libsolidcontrolifaces.so.4 libsolidcontrolifaces.so )
+( cd opt/kde/lib ; rm -rf libkdecorations.so.4 )
+( cd opt/kde/lib ; ln -sf libkdecorations.so.4.3.0 libkdecorations.so.4 )
+( cd opt/kde/lib ; rm -rf libkscreensaver.so )
+( cd opt/kde/lib ; ln -sf libkscreensaver.so.5 libkscreensaver.so )
+( cd opt/kde/lib ; rm -rf libsolidcontrol.so )
+( cd opt/kde/lib ; ln -sf libsolidcontrol.so.4 libsolidcontrol.so )
+( cd opt/kde/lib ; rm -rf libprocesscore.so )
+( cd opt/kde/lib ; ln -sf libprocesscore.so.4 libprocesscore.so )
+( cd opt/kde/lib ; rm -rf libprocesscore.so.4 )
+( cd opt/kde/lib ; ln -sf libprocesscore.so.4.3.0 libprocesscore.so.4 )
+( cd opt/kde/lib ; rm -rf liblsofui.so )
+( cd opt/kde/lib ; ln -sf liblsofui.so.4 liblsofui.so )
+( cd opt/kde/lib ; rm -rf libkfontinstui.so )
+( cd opt/kde/lib ; ln -sf libkfontinstui.so.4 libkfontinstui.so )
+( cd opt/kde/lib ; rm -rf libtime_solar.so )
+( cd opt/kde/lib ; ln -sf libtime_solar.so.4 libtime_solar.so )
+( cd opt/kde/lib ; rm -rf libkwineffects.so.1 )
+( cd opt/kde/lib ; ln -sf libkwineffects.so.1.0.0 libkwineffects.so.1 )
+( cd opt/kde/lib ; rm -rf libnepomukqueryclient.so )
+( cd opt/kde/lib ; ln -sf libnepomukqueryclient.so.4 libnepomukqueryclient.so )
+( cd opt/kde/lib ; rm -rf libkfontinstui.so.4 )
+( cd opt/kde/lib ; ln -sf libkfontinstui.so.4.3.0 libkfontinstui.so.4 )
+( cd opt/kde/lib ; rm -rf libplasma_applet-system-monitor.so.4 )
+( cd opt/kde/lib ; ln -sf libplasma_applet-system-monitor.so.4.3.0 libplasma_applet-system-monitor.so.4 )
+( cd opt/kde/lib ; rm -rf libtaskmanager.so )
+( cd opt/kde/lib ; ln -sf libtaskmanager.so.4 libtaskmanager.so )
+( cd opt/kde/lib ; rm -rf libtaskmanager.so.4 )
+( cd opt/kde/lib ; ln -sf libtaskmanager.so.4.3.0 libtaskmanager.so.4 )
+( cd opt/kde/lib ; rm -rf libplasma_applet-system-monitor.so )
+( cd opt/kde/lib ; ln -sf libplasma_applet-system-monitor.so.4 libplasma_applet-system-monitor.so )
+( cd opt/kde/lib ; rm -rf libprocessui.so.4 )
+( cd opt/kde/lib ; ln -sf libprocessui.so.4.3.0 libprocessui.so.4 )
+( cd opt/kde/lib ; rm -rf libksgrd.so )
+( cd opt/kde/lib ; ln -sf libksgrd.so.4 libksgrd.so )
+( cd opt/kde/lib ; rm -rf libsolidcontrolifaces.so.4 )
+( cd opt/kde/lib ; ln -sf libsolidcontrolifaces.so.4.3.0 libsolidcontrolifaces.so.4 )
+( cd opt/kde/lib ; rm -rf libkdecorations.so )
+( cd opt/kde/lib ; ln -sf libkdecorations.so.4 libkdecorations.so )
+( cd opt/kde/lib ; rm -rf libsolidcontrol.so.4 )
+( cd opt/kde/lib ; ln -sf libsolidcontrol.so.4.3.0 libsolidcontrol.so.4 )
+( cd opt/kde/lib ; rm -rf liblsofui.so.4 )
+( cd opt/kde/lib ; ln -sf liblsofui.so.4.3.0 liblsofui.so.4 )
+( cd opt/kde/lib ; rm -rf libkwineffects.so )
+( cd opt/kde/lib ; ln -sf libkwineffects.so.1 libkwineffects.so )
+( cd opt/kde/lib ; rm -rf libnepomukquery.so )
+( cd opt/kde/lib ; ln -sf libnepomukquery.so.4 libnepomukquery.so )
+( cd opt/kde/lib ; rm -rf libplasmaclock.so )
+( cd opt/kde/lib ; ln -sf libplasmaclock.so.4 libplasmaclock.so )
+( cd opt/kde/lib ; rm -rf libtime_solar.so.4 )
+( cd opt/kde/lib ; ln -sf libtime_solar.so.4.3.0 libtime_solar.so.4 )
+( cd opt/kde/lib ; rm -rf libpolkitkdeprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libpolkitkdeprivate.so.4.3.0 libpolkitkdeprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libplasma-geolocation-interface.so )
+( cd opt/kde/lib ; ln -sf libplasma-geolocation-interface.so.4 libplasma-geolocation-interface.so )
+( cd opt/kde/lib ; rm -rf libweather_ion.so )
+( cd opt/kde/lib ; ln -sf libweather_ion.so.4 libweather_ion.so )
+( cd opt/kde/lib ; rm -rf libkwinnvidiahack.so.4 )
+( cd opt/kde/lib ; ln -sf libkwinnvidiahack.so.4.3.0 libkwinnvidiahack.so.4 )
+( cd opt/kde/lib ; rm -rf libkworkspace.so.4 )
+( cd opt/kde/lib ; ln -sf libkworkspace.so.4.3.0 libkworkspace.so.4 )
+( cd opt/kde/lib ; rm -rf libnepomukqueryclient.so.4 )
+( cd opt/kde/lib ; ln -sf libnepomukqueryclient.so.4.3.0 libnepomukqueryclient.so.4 )
+( cd opt/kde/lib ; rm -rf libkephal.so )
+( cd opt/kde/lib ; ln -sf libkephal.so.4 libkephal.so )
+( cd opt/kde/lib ; rm -rf libweather_ion.so.4 )
+( cd opt/kde/lib ; ln -sf libweather_ion.so.4.3.0 libweather_ion.so.4 )
+#%% begin initialize kdebase-workspace-4.3.1
+if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
+	/bin/bash /opt/kde/bin/plamo_update_kde.sh
+fi
+#%% end
